import value1 from './generated-name.js';
import value2 from './generated-firstName.js';
import value3 from './generated-name2.js';

console.log('main', value1, value2, value3);
